@@ -8,10 +8,10 @@ use snafu::Snafu;
 #[derive(Debug, Snafu)]
 pub enum Error {
     #[snafu(display("libc deb error: {}", source))]
-    DebError { source: libc_deb::Error },
+    Deb { source: libc_deb::Error },
 
     #[snafu(display("failed writing to linker file: {}", source))]
-    WriteError { source: std::io::Error },
+    Write { source: std::io::Error },
 }
 
 pub type Result = std::result::Result<(), Error>;
@@ -23,6 +23,6 @@ pub fn fetch_ld(ver: &LibcVersion) -> Result {
 
     let deb_file_name = format!("libc6_{}.deb", ver);
     let ld_name = format!("ld-{}.so", ver.string_short);
-    libc_deb::write_ubuntu_pkg_file(&deb_file_name, &ld_name, &ld_name).context(DebError)?;
+    libc_deb::write_ubuntu_pkg_file(&deb_file_name, &ld_name, &ld_name).context(DebSnafu)?;
     Ok(())
 }
